========================
 Storlets Release Notes
========================

.. toctree::
   :maxdepth: 1

   current

   2024.1

   2023.2

   2023.1

   zed

   yoga

   xena

   wallaby

   victoria

   ussuri

   train

   stein

   rocky

   queens
